@@ -131,7 +131,7 @@ if ( $_POST["action"]=="mingsenupload")
 //	if($attach_ext == 'php' || empty($attach_ext) || !@in_array($attach_ext,$available_type)){
 //		showerror('對不起，您上傳的文件類型已被系統禁止！');
 //	}
-	if($attach_ext != '.xls' && $attach_ext != '.cvs'){
+	if($attach_ext != 'xls' && $attach_ext != 'csv'){
 		WriteErrMsg('The type of file you uploaded has been banned!');
 	}
 	$randvar=num_rand('15');
