@@ -130,7 +130,7 @@ if(isset($_GET['action'])) {
 			//      if($attach_ext == 'php' || empty($attach_ext) || !@in_array($attach_ext,$available_type)){
 			//              showerror('对不起，您上传的文件类型已被系统禁止！');
 			//      }
-			if($attach_ext != '.xls' && $attach_ext != '.cvs'){
+			if($attach_ext != 'xls' && $attach_ext != 'csv'){
 				WriteErrMsg('对不起，您上传的文件类型已被系统禁止！');
 			}
 
